############################################################################################################
# Version: 14 January 2015
# 
# Author: Roel Brienen 
#
# When using these data please cite the original article:
#      R.J.W. Brienen*, O.L. Phillips*, T.R. Feldpausch, E. Gloor, T.R. Baker, J. Lloyd, G. Lopez-Gonzalez et al. 
#      Long-term decline of the Amazon carbon sink
# See: http://dx.doi.org/10.5521/ForestPlots.net/2014_4
#
############################################################################################################

rm(list=ls(all=TRUE))

# set your own working directory
setwd("xxxx")

#Packages required:  
library(maps);library(graphics);library(shape); library(plotrix) ;library(maptools); library(mapdata); 

weighting = "by_plot_size" ; var= "AGBnetchange" ; interval_start =1980 ; interval_end=2011.5
plot_level="plot" ; min_interval = 10 
  
############################################################################################################
# DATASETS REQUIRED:

metadata=read.csv(file="metadata.csv")
dataSel_wss=read.csv(file="data_by_cens.csv")

# set time window for analysis
I=which(dataSel_wss$mid_int_date <= interval_end & dataSel_wss$mid_int_date >= interval_start)
dataSel_wss = dataSel_wss[I,]

############################################################################################################

# add decade to variables
dataSel_wss$decade = floor(dataSel_wss$mid_int_date/10)*10

 ### Create empty dataframe to write the slope estimates ##############################################################
variabl=c("AGBnetchange","AGBMor_tot","AGBGain_tot","N_mort_plus_rec")
plot=as.character(levels(dataSel_wss$PlotViewName))
slopes_data=data.frame(PlotViewName=plot, 
                       intcpAGBnetchange =rep(0), slpAGBnetchange=rep(0), p_value=rep(0),
                       intcpAGBMor_tot=rep(0), slpAGBMor_tot=rep(0), p_value=rep(0), 
                       intcpAGBGain_tot=rep(0), slpAGBGain_tot=rep(0), p_value=rep(0), 
                       intcpN_mort_plus_rec =rep(0), slpN_mort_plus_rec=rep(0), p_value=rep(0), 
                       intcpMort_plus_Gain=rep(0), slpMort_plus_Gain=rep(0), p_value=rep(0))
##################################################################################################################

# calculate slope estimates for each variable  
for(k in 1:4) {
var=variabl[[k]] 

  for (i in 1: length(levels(dataSel_wss$PlotViewName))) { 
    I=which(dataSel_wss$PlotViewName==levels(dataSel_wss$PlotViewName)[i])  
    intcp=NA; slp=NA; p_value=NA
    if( length(I)>2                            # only if 3 or more census intervals available
        & is.finite(dataSel_wss[I[1],c(var)])  # only if there are data in dataSel (some NA's)
        & 1990 %in% dataSel_wss[I,"decade"]    # only if at least one point in 90s
        & 2000 %in% dataSel_wss[I,"decade"])   # and one point in 2000s
        {
            linmodel=lm(dataSel_wss[I,c(var)]~dataSel_wss[I,"mid_int_date"], weight=dataSel_wss[I,"int_c_length"])# weighted by cenuss interval length
            intcp <- coef(linmodel)[[1]]
            slp <-  coef(linmodel)[[2]]
            p_value <-   coef(summary(linmodel))[2,"Pr(>|t|)"]
        }
    slopes_data[i,2+3*(k-1)]=intcp
    slopes_data[i,3+3*(k-1)]=slp
    slopes_data[i,4+3*(k-1)]=p_value
   }
}

### add some data from dataSel to slope values 
xxx=dataSel_wss[,c("PlotViewName", "tot_monitor_length", "int_ini", "int_fin", "plot_area", "N_plots")]
data_to_add=ddply(xxx, .(PlotViewName), 
          function(x) data.frame(
            tot_monitor_length= mean(x$tot_monitor_length, na.rm=T),
            PlotArea.mean = mean(x$plot_area, na.rm=T),
            N_plots.mean = mean(x$N_plots, na.rm=T),
            int_ini= min(x$int_ini, na.rm=T),
            int_fin= max(x$int_fin, na.rm=T)))
data_slp=merge(slopes_data, data_to_add, by="PlotViewName")

# Add total weight to each plot based on plot area times total census interval 
I=which(data_slp$tot_monitor_length>(interval_end-interval_start)) # which tot monitor length exceeds time window
data_slp[I,c("tot_monitor_length")]=(interval_end-interval_start)  # reset those exceeding time window to max length
data_slp$weight= data_slp$PlotArea.mean^0.5*data_slp$tot_monitor_length 

# Add coordinates to slope values 
metadataSel=metadata[,c("PlotViewName", "LatitudeDecimal", "LongitudeDecimal", "ClusterCode")]
data_slp=merge(data_slp, metadataSel, by="PlotViewName", all.y=F, all.x=T, incomparables=T)

# Only use plots with data longer than minimum total interval length (set at 10 years) 
data_slp_plot=data_slp[which(data_slp$tot_monitor_length>min_interval),]

data_slp_10=data_slp_plot # data_slp_10 is datafile to use for plotting

##################################################################################################################################  
# plot individual lines for each plot
##################################################################################################################################

r=100  # set number of bootstraps for CI
nss_interval_start=1980 
nss_interval_end=2011.5 
years=seq(1980,2011.5,0.1)
  
ii=which(is.finite(data_slp_plot$slpAGBnetchange))
N_units= length(ii)
N_plots= sum(data_slp_plot[ii,c("N_plots.mean")])
print(N_units)
print(N_plots)

quartz("Ms Figs 2abc")

##################################################################################################################################
# first panel for net biomass change

  par(fig=c(0, 1,0.69,1), omi=c(0,0.4,0,0),mai=c(0,0,0,0), mar=c(0.1, 0.5, .1, .1) + 0.1) 
  plot(NA,NA,axes=F,xlim=c(0,10),ylim=c(0,10),xlab="",ylab="")
  
  text(2,9.5,paste("Change in net biomass change"), cex=1, pos=4)  
   
  x="slpAGBnetchange"       
  p=signif(t.test(data_slp_10[,c(x)])[["p.value"]],2)  
  slp=weighted.mean(data_slp_10[,c(x)],(data_slp_10$weight), na.rm=T)
  text(2,8.5, bquote("Mean slope =" ~ .(round(slp, 3)) ~ "Mg" ~ ha^-1 ~ ~yr^-2),  cex=0.7, pos=4)
  text(2,7.75, paste("p=",p), cex=0.7, pos=4)  
  
  par(new=T) ; par(mgp = c(0, .5, 0), cex.axis=0.5, cex.lab=0.7)   
  par(fig=c(0,1,0.68,0.95), omi=c(0,0.4,0,0),mai=c(0,0,0,0), mar=c(0.1, 0.5, .1, .1) + 0.1)
  l=which(colnames(data_slp_10)=="intcpAGBnetchange") # rel change
  plot(1,1, ylim=c(-5,5), xlim=c(1980,2010), xlab="",  xaxt="n", ylab="", tck=-0.02, frame =F, cex.axis=0.7, cex.lab=1)#, ylab="Change in Biomass change")
  mtext(expression("Change in net change (Mg ha"^"-1"*"yr"^"-2"*")"), side=2,line=1.3, cex=0.7)# ; axis(2, cex.axis=0.7, cex.lab=0.7, cex.axis=0.5,tck=-0.02,line=0.5)

# procedure to plot lines
for (i in 1: length(data_slp_10$slpAGBnetchange)) { 
  intcp <- data_slp_10[i,l]
  slp <-  data_slp_10[i,l+1]
  if(is.finite(slp)){
    x1=seq(data_slp_10[i,c("int_ini")],data_slp_10[i,c("int_fin")], 0.1); 
    x2=(x1-mean(x1))
    predic=slp*x2 
    if(slp>0) 
    {lines(x1, predic, col="green4", lwd=0.5)}
    if(slp<=0)
    {lines(x1, predic, col="red", lwd=0.5, xlim=c(nss_interval_start,nss_interval_end))}
  }
}
slp=weighted.mean(data_slp_10[,l+1],(data_slp_10$weight), na.rm=T)
predic=slp*(years-mean(years)); lines(years, predic, col="black", lwd=1.5)
x=data_slp_10[,l+1]
slp_ci=quantile(boot(x, function(x, d) mean(x[d], na.rm=TRUE), weight=((data_slp_10$weight)), sim="balanced", R=r)$t, c(0.975, 0.025), na.rm=TRUE)
slp1=slp_ci[1]; predic=slp1*(years-mean(years)); lines(years, predic, col="black", lwd=1.5 )
slp2=slp_ci[2]; predic=slp2*(years-mean(years)); lines(years, predic, col="black", lwd=1.5)
  
par(new=T) ; par(fig=c(0.7,0.95,0.85,1), omi=c(0,0,0,0),mai=c(0,0,0,0), mar=c(1.5, 1.5, .1, .1) + 0.1)
par(mgp = c(0.7,.01, 0))
  x="slpAGBnetchange"     
  hist(data_slp_10[,c(x)], breaks=6, #c(-0.3,-0.2,-0.1, 0, 0.1, 0.2, 0.3), 
       tck=-0.02, main="", ylab="Freq.",xlab="Slope", col="grey70")#, cex.axis=0.5, cex.lab=0.7,) 
  abline(v=0, col="red")
  
  
##################################################################################################################################
  par(new=T); par(fig=c(0, 1,0.39,0.73), omi=c(0,0.4,0,0),mai=c(0,0,0,0), mar=c(0.1, 0.5, .1, .1) + 0.1)  
  plot(NA,NA,axes=F,xlim=c(0,10),ylim=c(0,10),xlab="",ylab="")
  text(2,9.5,paste("Change in productivity"), cex=1, pos=4)
  x="slpAGBGain_tot"   
  p=signif(t.test(data_slp_10[,c(x)])[["p.value"]],2)  
 
  slp=weighted.mean(data_slp_10[,c(x)],(data_slp_10$weight), na.rm=T)
  text(2,8.5, bquote("Mean slope =" ~ .(round(slp, 3)) ~ "Mg" ~ ha^-1 ~ ~yr^-2),  cex=0.7, pos=4)
  if(p<0.001) {text(2,7.75,pos=4, bquote("p<0.001"), cex=0.7)} 
  if(p>0.001) {text(2,7.75, paste("p=",p), cex=0.7, pos=4)}


#################################################################################################################################
# second panel for gains

  par(new=T) ; par(fig=c(0,1,0.38,0.67), omi=c(0,0.4,0,0),mai=c(0,0,0,0), mar=c(0.1, 0.5, .1, .1) + 0.1)
  par(mgp = c(0, .5, 0), cex.axis=0.5, cex.lab=0.7)  
  l=which(colnames(data_slp_10)=="intcpAGBGain_tot")  # gains_rel
  plot(1,1, ylim=c(-5,5), xlim=c(1980,2010), xlab="",  ylab="", xaxt="n", cex.axis=0.7, cex.lab=1, tck=-0.02, frame =F)#, ylab="Change in Biomass change")
  mtext(expression("Change in productivity (Mg ha"^"-1"*"yr"^"-2"*")"), side=2,line=1.3, cex=0.7)
  
for (i in 1: length(data_slp_10$slpAGBnetchange)) { 
  intcp <- data_slp_10[i,l]
  slp <-  data_slp_10[i,l+1]
  if(is.finite(slp)){
    x1=seq(data_slp_10[i,c("int_ini")],data_slp_10[i,c("int_fin")], 0.1)
    x2=x1-mean(x1)
    predic=slp*x2 #+intcp
    if(slp>0) 
    {lines(x1, predic, col="green4", lwd=0.5, xlim=c(nss_interval_start,nss_interval_end))}
    if(slp<=0)
    {lines(x1, predic, col="red", lwd=0.5, xlim=c(nss_interval_start,nss_interval_end))}
  }
}
slp=weighted.mean(data_slp_10[,l+1],(data_slp_10$weight), na.rm=T)
predic=slp*(years-mean(years)); lines(years, predic, col="black", lwd=1.5)
x=data_slp_10[,l+1]
slp_ci=quantile(boot(x, function(x, d) mean(x[d], na.rm=TRUE), weight=((data_slp_10$weight)), sim="balanced", R=r)$t, c(0.975, 0.025), na.rm=TRUE)
slp1=slp_ci[1]; predic=slp1*(years-mean(years)); lines(years, predic, col="black", lwd=1.5 )
slp2=slp_ci[2]; predic=slp2*(years-mean(years)); lines(years, predic, col="black", lwd=1.5)
  
 
par(new=T) ;par(fig=c(0.1,0.35,0.57,0.72), omi=c(0,0,0,0),mai=c(0,0,0,0), mar=c(1.5, 1.5, .1, .1) + 0.1)
  par(mgp = c(0.7,.01, 0))
  x="slpAGBGain_tot"     
hist(data_slp_10[,c(x)], breaks=6, #c(-0.15, -0.1, -0.05, 0, 0.05, 0.1, 0.15, 0.2), 
     tck=-0.02, main="", ylab="Freq.",xlab="Slope", col="grey70")#
abline(v=0, col="red")
       
       
#################################################################################################################################
# third panel for mortality

par(new=T); par(fig=c(0, 1,0, 0.41), omi=c(0.4,0.4,0,0),mai=c(0,0,0,0), mar=c(0.1, 0.5, .1, .1) + 0.1)     
  plot(NA,NA,axes=F,xlim=c(0,10),ylim=c(0,10),xlab="",ylab="")
  text(2,9.5,paste("Change in biomass mortality"), cex=1, pos=4)
  x="slpAGBMor_tot" 
  p=signif(t.test(data_slp_10[,c(x)])[["p.value"]],2)  
  slp=weighted.mean(data_slp_10[,c(x)],(data_slp_10$weight), na.rm=T)
  text(2,8.5, bquote("Mean slope =" ~ .(round(slp, 3)) ~ "Mg" ~ ha^-1 ~ ~yr^-2),  cex=0.7, pos=4)
 
  if(p<0.001) {text(2,7.75,pos=4, bquote("p<0.001"), cex=0.7)} 
  if(p>0.001) {text(2,7.75, paste("p=",p), cex=0.7, pos=4)}

  par(new=T); par(mgp = c(0, .5, 0), cex.axis=0.5, cex.lab=0.7)
  par(fig=c(0,1,0,0.33), omi=c(0.4,0.4,0,0),mai=c(0,0,0,0), mar=c(1, 0.5, .1, .1) + 0.1)
  l=which(colnames(data_slp_10)=="intcpAGBMor_tot") # mort_rel
  plot(1,1, ylim=c(-5,5), xlim=c(1980,2010),  xlab="",  ylab="", xaxt="n", cex.axis=0.7, cex.lab=1, tck=-0.02, frame =F)#, ylab="Change in Biomass change")
  mtext(expression("Change in mortality (Mg ha"^"-1"*"yr"^"-2"*")"), side=2,line=1.3, cex=0.7)
  axis(side=1, line=0.5, cex.axis=0.7) ; mtext("Year", side=1,line=2, cex=1)
  
for (i in 1: length(data_slp_10$slpAGBnetchange)) { 
  intcp <- data_slp_10[i,l]
  slp <-  data_slp_10[i,l+1]
  if(is.finite(slp)){
    x1=seq(data_slp_10[i,c("int_ini")],data_slp_10[i,c("int_fin")], 0.1)
    x2=x1-mean(x1)
    predic=slp*x2 #+intcp
    if(slp>0) 
    {lines(x1, predic, col="red", lwd=0.5, xlim=c(nss_interval_start,nss_interval_end))}
    if(slp<=0)
    {lines(x1, predic, col="green4", lwd=0.5, xlim=c(nss_interval_start,nss_interval_end))}
  }
}
slp=weighted.mean(data_slp_10[,l+1],(data_slp_10$weight), na.rm=T)
predic=slp*(years-mean(years)); lines(years, predic, col="black", lwd=1.5)
x=data_slp_10[,l+1]
slp_ci=quantile(boot(x, function(x, d) mean(x[d], na.rm=TRUE), weight=((data_slp_10$weight)), sim="balanced", R=r)$t, c(0.975, 0.025), na.rm=TRUE)
slp1=slp_ci[1]; predic=slp1*(years-mean(years)); lines(years, predic, col="black", lwd=1.5, )
slp2=slp_ci[2]; predic=slp2*(years-mean(years)); lines(years, predic, col="black", lwd=1.5)
  
par(new=T) ;par(fig=c(0.1,0.35, 0.25,0.40),  omi=c(0,0,0,0),mai=c(0,0,0,0), mar=c(1.5, 1.5, .1, .1) + 0.1)
  par(mgp = c(0.7,.01, 0))
  x="slpAGBMor_tot" 
  hist(data_slp_10[,c(x)], breaks=6, #c(-0.3, -0.2, -0.1, 0, 0.1, 0.2, 0.3),  
       tck=-0.02, main="", ylab="Freq.",xlab="Slope", col="grey70")#
  abline(v=0, col="red")

##################################################################################################################################
# Plot maps at cluster level
##################################################################################################################################

# To plot on map, use cluster level data (otherwise figure unreadable)
# create new file wiht averages of change at cluster level 
data_slp_lim=data_slp_plot[which(is.finite(data_slp_plot$intcpAGBnetchange)),]# delete plots without data for netchange
data_clust_slp= ddply(data_slp_lim, .(ClusterCode), 
                      function(x) data.frame(
                        intcpAGBnetchange      =  weighted.mean(x$intcpAGBnetchange,(x$weight), na.rm=T), 
                        slpAGBnetchange        =  weighted.mean(x$slpAGBnetchange, (x$weight),na.rm=T),            
                        intcpAGBMor_tot       =   weighted.mean(x$intcpAGBMor_tot,(x$weight), na.rm=T),
                        slpAGBMor_tot         =   weighted.mean(x$slpAGBMor_tot, (x$weight),na.rm=T),  
                        intcpAGBGain_tot      =   weighted.mean(x$intcpAGBGain_tot,(x$weight), na.rm=T),
                        slpAGBGain_tot        =   weighted.mean(x$slpAGBGain_tot,(x$weight), na.rm=T),
                        PlotArea.mean         =   sum(x$PlotArea.mean),
                        tot_monitor_length    =   sum(x$tot_monitor_length),
                        int_ini               =   min(x$int_ini, na.rm=T),
                        int_fin               =   max(x$int_fin, na.rm=T),
                        weight                =   sum(x$weight),
                        LatitudeDecimal       = mean(x$LatitudeDecimal, na.rm=T),
                        LongitudeDecimal      = mean(x$LongitudeDecimal, na.rm=T)))
data_slp_10=data_clust_slp 
data_slp_10$LatitudeDecimal_round=round(data_slp_10$LatitudeDecimal,digits=0)
data_slp_10$LongitudeDecimal_round=round(data_slp_10$LongitudeDecimal,digits=0)
  
# procedure to offset overlapping coordinates
  plot.new()
  xy=cluster.overplot(data_slp_10$LongitudeDecimal_round, rep(1,length(data_slp_10$LatitudeDecimal_round)),away=0.5)
  data_slp_10$LatitudeDecimal_off = data_slp_10$LatitudeDecimal
  data_slp_10$LongitudeDecimal_off =xy$x
  
# dimensions for arrows
  base=1; length_arr=2; length_head=0.1 ;   width_arr=0.1
  y_bor=c(-20,12.5); x_bor=c(-82.5,-42.5 )

##################################################################################################################################
  quartz("Ms Figs 2def")
  par(mfrow=c(3,1))#, mar=c(2,4,2,2))
##################################################################################################################################
  
  x="slpAGBnetchange"       
  map(database = "world", ylim=y_bor, xlim=x_bor, mar=c(0.1,0.1,0.1,0.1)) 
  map.scale(-55, 10, relwidth=0.2, metric=T, ratio=F, cex=0.8) # subdiv)
  map('rivers', add =TRUE, col="blue")
  abline(h=0)  ; box()
  
  # divide dataset
  pos_change=droplevels(subset(data_slp_10, data_slp_10[,c(x)] > 0))
  neg_change=droplevels(subset(data_slp_10, data_slp_10[,c(x)] < 0)) 
  with(pos_change,Arrows(LongitudeDecimal_off, LatitudeDecimal_off, x1=LongitudeDecimal_off,
                         y1=LatitudeDecimal_off+base+length_arr*pos_change[,c(x)], col="green4", 
                         arr.length = length_head, 
                         arr.width =width_arr, arr.adj = 0.5, code = 2,  lty = 1, lwd = 2, arr.type="triangle"))
  with(neg_change,Arrows(LongitudeDecimal_off, LatitudeDecimal_off, x1=LongitudeDecimal_off,
                        y1=LatitudeDecimal_off-base+length_arr*neg_change[,c(x)], col="red", 
                        arr.length = length_head, 
                        arr.width = width_arr, arr.adj =0.5, code = 2,  lty = 1, lwd = 2, arr.type="triangle"))

##################################################################################################################################

  x="slpAGBGain_tot"   
  map(database = "world",  ylim=y_bor, xlim=x_bor, mar=c(0.1,0.1,0.1,0.1))
  map('rivers', add =TRUE, col="blue")
    abline(h=0)  ; box()
  
  # divide dataset
  pos_change=droplevels(subset(data_slp_10, data_slp_10[,c(x)] > 0))
  neg_change=droplevels(subset(data_slp_10, data_slp_10[,c(x)] < 0))
  with(pos_change,Arrows(LongitudeDecimal_off, LatitudeDecimal_off, x1=LongitudeDecimal_off,
                         y1=LatitudeDecimal_off+base+length_arr*pos_change[,c(x)], col="green4", 
                         arr.length = length_head, 
                         arr.width =width_arr, arr.adj = 0.5, code = 2,  lty = 1, lwd = 2, arr.type="triangle"))
  with(neg_change,Arrows(LongitudeDecimal_off, LatitudeDecimal_off, x1=LongitudeDecimal_off,
                         y1=LatitudeDecimal_off-base+length_arr*neg_change[,c(x)], col="red", 
                         arr.length = length_head, 
                         arr.width = width_arr, arr.adj =0.5, code = 2,  lty = 1, lwd = 2, arr.type="triangle"))
##################################################################################################################################

  x="slpAGBMor_tot" 
  map(database = "world",  ylim=y_bor, xlim=x_bor, mar=c(0.1,0.1,0.1,0.1))
  map('rivers', add =TRUE, col="blue")
  abline(h=0)  ; box()
  
  # divide dataset
  pos_change=droplevels(subset(data_slp_10, data_slp_10[,c(x)] < 0))
  neg_change=droplevels(subset(data_slp_10, data_slp_10[,c(x)] > 0))
  with(pos_change,Arrows(LongitudeDecimal_off, LatitudeDecimal_off, x1=LongitudeDecimal_off,
                         y1=LatitudeDecimal_off-base+length_arr*pos_change[,c(x)], col="green4", 
                         arr.length = length_head, 
                         arr.width =width_arr, arr.adj = 0.5, code = 2,  lty = 1, lwd = 2, arr.type="triangle"))
  with(neg_change,Arrows(LongitudeDecimal_off, LatitudeDecimal_off, x1=LongitudeDecimal_off,
                         y1=LatitudeDecimal_off+base+length_arr*neg_change[,c(x)], col="red", 
                         arr.length = length_head, 
                         arr.width = width_arr, arr.adj =0.5, code = 2,  lty = 1, lwd = 2, arr.type="triangle"))
 
