
############################################################################################################
# Version: 14 January 2015
# 
# Author: Roel Brienen 
#
# When using these data please cite the original article:
#      R.J.W. Brienen*, O.L. Phillips*, T.R. Feldpausch, E. Gloor, T.R. Baker, J. Lloyd, G. Lopez-Gonzalez et al. 
#      Long-term decline of the Amazon carbon sink
# See: http://dx.doi.org/10.5521/ForestPlots.net/2014_4
#
############################################################################################################

rm(list=ls(all=TRUE))

# set your own working directory
setwd("xxxx")

# Packages required:  
library(plyr)

############################################################################################################
# DATASETS REQUIRED:
all_long=read.csv(file="data_long_1980.csv")

# set time window for analysis
interval_start =1983 ; interval_end=2011.5

I=which(all_long$year>=interval_start & all_long$year<= interval_end) # select time interval 
all_long_x=all_long[I,] # keep only data from within time interval

# create datapl;   contains plot by plot summaries of biomass dynamics for period 1983-2011.5
  I=which(all_long$year>=interval_start & all_long$year<= interval_end) # select time interval 
  all_long_x=all_long[I,] # keep only data from within time interval
  datapl= summaryBy(# plot summaries of variable from all-long for selected time interval 
    AGBnetchange
    +BAnetchange
    +N_change
    +WD_change
    +PlotArea
    +tot_monitor_length
    +N_units
    ~PlotViewName, 
    data=all_long_x, 
    FUN= c(mean), 
    na.rm=TRUE)  
  
# plot figures  
quartz("MS fig 3")
par(mfrow=c(1,3))
datapl$weight=(datapl$tot_monitor_length.mean)*(datapl$PlotArea.mean^0.5)
N_plots=sum(datapl[which(is.finite(datapl$BAnetchange.mean)), c("N_units.mean")])
N_units=length(which(is.finite(datapl$BAnetchange.mean)))
plot(datapl$AGBnetchange.mean , datapl$BAnetchange.mean, xlim=c(-8,8), ylim=c(-0.6,0.6), 
     xlab=expression("Net biomass change (Mg ha"^"-1"*"yr"^"-1"*")"),
     ylab=expression("Netchange BA (m "^"2"*" ha "^"-1"*"yr"^"-1"*")"), 
     main= "a) Basal Area change")
linmod=lm(datapl$AGBnetchange.mean ~ datapl$BAnetchange.mean)
r=round(summary(linmod)$r.squared,3)
p=round(summary(linmod)$coefficients[[8]], 4)
mean=round(weighted.mean(datapl$BAnetchange.mean, na.rm=T, weight=datapl$weight),2)
text(-7,0.55, paste("Mean =",mean, ", n=",N_plots, "plots"),pos=4, cex=1)
text(-7,0.475, bquote("R"^2~"=" ~.(r) ~", p< 0.001"), cex=1, pos=4)
abline(h=0,v=0, col = "gray60", lwd=0.7)

N_plots=sum(datapl[which(is.finite(datapl$N_change.mean)), c("N_units.mean")])
N_units=length(which(is.finite(datapl$N_change.mean)))
plot(datapl$AGBnetchange.mean, datapl$N_change.mean, xlim=c(-8,8), ylim=c(-6,6), 
     xlab=expression("Net biomass change (Mg ha"^"-1"*"yr"^"-1"*")"),
     ylab=expression("Change rates in number of stems (ha"^"-1"*"yr"^"-1"*")"), 
     main= "b) Stem change")
linmod=lm(datapl$AGBnetchange.mean ~ datapl$N_change.mean)
r=round(summary(linmod)$r.squared, 4)
p=round(summary(linmod)$coefficients[[8]], 4)
mean=round(weighted.mean(datapl$N_change.mean, na.rm=T, weight=datapl$weight),2)
text(-7,5.75, paste("Mean =",mean, ", n=",N_plots, "plots"),pos=4, cex=1)
text(-7,5,   bquote("R"^2~"=" ~.(r) ~", p< 0.001"), cex=1, pos=4)
abline(h=0,v=0, col = "gray60", lwd=0.7)

N_plots=sum(datapl[which(is.finite(datapl$WD_change.mean)), c("N_units.mean")])
N_units=length(which(is.finite(datapl$WD_change.mean)))
plot(datapl$AGBnetchange.mean, datapl$WD_change.mean, xlim=c(-8,8), ylim=c(-0.004,0.004), 
     xlab=expression("Net biomass change (Mg ha"^"-1"*"yr"^"-1"*")"),
     ylab=expression("Change rates wood density (g/cm"^"3"*"yr"^"-1"*")"), 
     main= "c) Wood density change")
linmod=lm(datapl$AGBnetchange.mean ~ datapl$WD_change.mean)
mean=round(weighted.mean(datapl$WD_change.mean, na.rm=T, weight=datapl$weight),2)
r=round(summary(linmod)$r.squared, 4)
p=round(summary(linmod)$coefficients[[8]], 4)
text(-7,0.00375, paste("Mean=", mean, ", n=",N_plots, "plots"),cex=1, pos=4)
text(-7,0.00325,  bquote("R"^2~"=" ~.(r) ~", p="~.(p)), cex=1, pos=4)
abline(h=0,v=0, col = "gray60", lwd=0.7)

